
grgrjax
=======

This library provides some additional tools to JAX, such as Newtons method or vectorized JVP and VJP functions.

Installation with ``pip``
-----------------------------

It's as simple as typing

.. code-block:: bash

   pip install grgrjax

in the terminal (Unix/Mac) or the Anaconda Prompt (Win).
